==> haskell-data-fix-0.3.1-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-fix
version:              0.3.1
visibility:           public
id:                   data-fix-0.3.1-I9kyIrsT6UuKr9NkkyFtR2
key:                  data-fix-0.3.1-I9kyIrsT6UuKr9NkkyFtR2
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  2e1b7b21bfc91be907a6b4b2dd78b615
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-fix-0.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-fix-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-fix-0.3.1
hs-libraries:         HSdata-fix-0.3.1-I9kyIrsT6UuKr9NkkyFtR2
depends:
    base-4.15.0.0 deepseq-1.4.5.0
    hashable-1.3.2.0-FeHuXTZofY1HfsvuXYo4tc

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-fix-0.3.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-fix
version:              0.3.2
visibility:           public
id:                   data-fix-0.3.2-BcCN859mYy7GUJM9opuiZj
key:                  data-fix-0.3.2-BcCN859mYy7GUJM9opuiZj
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  8ecfddadaace9d82fbc1cafc2da4d5ce
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.0.1/site-local/data-fix-0.3.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/data-fix-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/data-fix-0.3.2
hs-libraries:         HSdata-fix-0.3.2-BcCN859mYy7GUJM9opuiZj
depends:
    base-4.15.0.0 deepseq-1.4.5.0
    hashable-1.3.2.0-2579b4ed8EpGiVuNwiQjKE

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
